@@ -39,12 +39,8 @@ p11_crypto_plugin_opts = [
     cfg.StrOpt('token_serial_number',
                help=u._('Token serial number used to identify the token to be '
                         'used.')),
-    cfg.StrOpt('token_label',
-               deprecated_for_removal=True,
-               help=u._('DEPRECATED: Use token_labels instead. '
-                        'Token label used to identify the token to '
-                        'be used.')),
     cfg.ListOpt('token_labels',
+                default=[],
                 help=u._('List of labels for one or more tokens to be used. '
                          'Typically this is a single label, but some HSM '
                          'devices may require more than one label for Load '
